@@ -42,7 +42,7 @@ class Q_DECL_EXPORT KScreenDaemon : public KDEDModule
 
     public:
         KScreenDaemon(QObject *parent, const QList<QVariant>&);
-        virtual ~KScreenDaemon();
+        ~KScreenDaemon() override;
 
     public Q_SLOTS:
         virtual void requestConfig();
@@ -62,7 +62,10 @@ class Q_DECL_EXPORT KScreenDaemon : public KDEDModule
         void showOutputIdentifier();
         void applyOsdAction(KScreen::OsdAction::Action action);
 
+        // DBus
+        void applyLayoutPreset(const QString &presetName);
     Q_SIGNALS:
+        // DBus
         void outputConnected(const QString &outputName);
         void unknownOutputConnected(const QString &outputName);
 
@@ -70,7 +73,6 @@ class Q_DECL_EXPORT KScreenDaemon : public KDEDModule
         virtual void doApplyConfig(const KScreen::ConfigPtr &config);
 
         void monitorConnectedChange();
-        static KScreen::OutputPtr findEmbeddedOutput(const KScreen::ConfigPtr &config);
         void disableOutput(KScreen::ConfigPtr &config, KScreen::OutputPtr &output);
         void showOsd(const QString &icon, const QString &text);
 
@@ -79,6 +81,7 @@ class Q_DECL_EXPORT KScreenDaemon : public KDEDModule
         QTimer* m_changeCompressor;
         QTimer* m_saveTimer;
         QTimer* m_lidClosedTimer;
+        KScreen::OsdManager *m_osdManager;
 };
 
 #endif /*KSCREEN_DAEMON_H*/
